@@ -1,15 +1,17 @@
 import nomad.api.exceptions
 
+from nomad.api.base import Requester
 
-class Regions(object):
+
+class Regions(Requester):
 
     """
     https://www.nomadproject.io/docs/http/regions.html
     """
     ENDPOINT = "regions"
 
-    def __init__(self, requester):
-        self._requester = requester
+    def __init__(self, **kwargs):
+        super(Regions, self).__init__(**kwargs)
 
     def __str__(self):
         return "{0}".format(self.__dict__)
@@ -22,7 +24,7 @@ class Regions(object):
 
     def __contains__(self, item):
         try:
-            regions = self._get()
+            regions = self.get_regions()
 
             for r in regions:
                 if r == item:
@@ -33,12 +35,12 @@ class Regions(object):
             return False
 
     def __len__(self):
-        regions = self._get()
+        regions = self.get_regions()
         return len(regions)
 
     def __getitem__(self, item):
         try:
-            regions = self._get()
+            regions = self.get_regions()
 
             for r in regions:
                 if r == item:
@@ -49,15 +51,9 @@ class Regions(object):
             raise KeyError
 
     def __iter__(self):
-        regions = self._get()
+        regions = self.get_regions()
         return iter(regions)
 
-    def _get(self, *args):
-        url = self._requester._endpointBuilder(Regions.ENDPOINT, *args)
-        nodes = self._requester.get(url)
-
-        return nodes.json()
-
     def get_regions(self):
         """ Returns the known region names.
 
@@ -68,4 +64,4 @@ class Regions(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get()
+        return self.request(method="get").json()
