@@ -1,5 +1,7 @@
+from nomad.api.base import Requester
 
-class Validate(object):
+
+class Validate(Requester):
 
     """
     The system endpoint is used to for system maintenance
@@ -11,8 +13,8 @@ class Validate(object):
 
     ENDPOINT = "validate"
 
-    def __init__(self, requester):
-        self._requester = requester
+    def __init__(self, **kwargs):
+        super(Validate, self).__init__(**kwargs)
 
     def __str__(self):
         return "{0}".format(self.__dict__)
@@ -23,12 +25,6 @@ class Validate(object):
     def __getattr__(self, item):
         raise AttributeError
 
-    def _post(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Validate.ENDPOINT, *args)
-        response = self._requester.post(url, json=kwargs.get("nomad_job_dict", {}))
-
-        return response.ok
-
     def validate_job(self, nomad_job_dict):
         """ This endpoint validates a Nomad job file. The local Nomad agent forwards the request to a server.
         In the event a server can't be reached the agent verifies the job file locally but skips validating driver
@@ -43,4 +39,4 @@ class Validate(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._post("job", nomad_job_dict=nomad_job_dict)
+        return self.request("job", json=nomad_job_dict, method="post")
